Struct proto_core::PartialProtoConfig
source · pub struct PartialProtoConfig {
pub env: Option<IndexMap<String, <EnvVar as Config>::Partial>>,
pub tools: Option<BTreeMap<Id, <ProtoToolConfig as Config>::Partial>>,
pub plugins: Option<BTreeMap<Id, PluginLocator>>,
pub settings: Option<<ProtoSettingsConfig as Config>::Partial>,
pub versions: Option<BTreeMap<Id, UnresolvedVersionSpec>>,
pub unknown: Option<FxHashMap<String, TomlValue>>,
}Fields
env: Option<IndexMap<String, <EnvVar as Config>::Partial>>tools: Option<BTreeMap<Id, <ProtoToolConfig as Config>::Partial>>plugins: Option<BTreeMap<Id, PluginLocator>>settings: Option<<ProtoSettingsConfig as Config>::Partial>versions: Option<BTreeMap<Id, UnresolvedVersionSpec>>unknown: Option<FxHashMap<String, TomlValue>>Trait Implementations
sourceimpl Clone for PartialProtoConfig
impl Clone for PartialProtoConfig
sourcefn clone(&self) -> PartialProtoConfig
fn clone(&self) -> PartialProtoConfig
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for PartialProtoConfig
impl Debug for PartialProtoConfig
sourceimpl Default for PartialProtoConfig
impl Default for PartialProtoConfig
sourcefn default() -> PartialProtoConfig
fn default() -> PartialProtoConfig
Returns the “default value” for a type. Read more
sourceimpl<'de> Deserialize<'de> for PartialProtoConfigwhere
PartialProtoConfig: Default,
impl<'de> Deserialize<'de> for PartialProtoConfigwhere
PartialProtoConfig: Default,
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialConfig for PartialProtoConfig
impl PartialConfig for PartialProtoConfig
type Context = ()
sourcefn default_values(context: &Self::Context) -> Result<Option<Self>, ConfigError>
fn default_values(context: &Self::Context) -> Result<Option<Self>, ConfigError>
sourcefn env_values() -> Result<Option<Self>, ConfigError>
fn env_values() -> Result<Option<Self>, ConfigError>
sourcefn extends_from(&self) -> Option<ExtendsFrom>
fn extends_from(&self) -> Option<ExtendsFrom>
When a setting is marked as extendable with
#[setting(extend)], this returns
ExtendsFrom with the extended sources, either a list of strings or a single string.
When no setting is extendable, this returns None.sourcefn finalize(self, context: &Self::Context) -> Result<Self, ConfigError>
fn finalize(self, context: &Self::Context) -> Result<Self, ConfigError>
Finalize the partial configuration by consuming it and populating all fields with a value.
Defaults values from
PartialConfig::default_values will be applied first, followed
by merging the current partial, and lastly environment variable values from
PartialConfig::env_values.sourceimpl PartialEq for PartialProtoConfig
impl PartialEq for PartialProtoConfig
sourcefn eq(&self, other: &PartialProtoConfig) -> bool
fn eq(&self, other: &PartialProtoConfig) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Schematic for PartialProtoConfig
impl Schematic for PartialProtoConfig
sourcefn generate_schema() -> SchemaType
fn generate_schema() -> SchemaType
Create and return a schema that models the structure of the implementing type.
The schema can be used to generate code, documentation, or other artifacts.
sourceimpl Serialize for PartialProtoConfig
impl Serialize for PartialProtoConfig
impl StructuralPartialEq for PartialProtoConfig